@@ -6,7 +6,7 @@ import pytz
 from django.utils.functional import LazyObject
 from requests import Session
 from requests.adapters import HTTPAdapter
-from urllib3.util.ssl_ import DEFAULT_CIPHERS
+from urllib3.util.ssl_ import DEFAULT_CIPHERS  # type:ignore
 from urllib3.util.ssl_ import create_urllib3_context
 from zeep import Client
 from zeep.cache import SqliteCache
