@@ -8,16 +8,20 @@ class AfipException(DjangoAfipException):
     """
 
     def __init__(self, response):
-        Exception.__init__(self, 'Error {}: {}'.format(
-            response.Errors.Err[0].Code,
-            response.Errors.Err[0].Msg,
-        ))
+        Exception.__init__(
+            self,
+            "Error {}: {}".format(
+                response.Errors.Err[0].Code,
+                response.Errors.Err[0].Msg,
+            ),
+        )
 
 
 class AuthenticationError(DjangoAfipException):
     """
     Raised when there is a non-specific error during an authentication attempt.
     """
+
     pass
 
 
@@ -25,6 +29,7 @@ class CertificateExpired(AuthenticationError):
     """
     Raised when an authentication was attempted with an expired certificate.
     """
+
     pass
 
 
@@ -32,6 +37,7 @@ class UntrustedCertificate(AuthenticationError):
     """
     Raise when an untrusted certificate is used in an authentication attempt.
     """
+
     pass
 
 
@@ -40,6 +46,7 @@ class CorruptCertificate(AuthenticationError):
     Raised when a corrupt ceritificate file is used in an authenticaiton
     attempt.
     """
+
     pass
 
 
