@@ -1,3 +1,5 @@
+from typing import List
+
 import django.db.models.deletion
 from django.db import migrations
 from django.db import models
@@ -48,7 +50,7 @@ class Migration(migrations.Migration):
 
     initial = True
 
-    dependencies = []
+    dependencies: List[str] = []
 
     operations = [
         migrations.CreateModel(
@@ -66,21 +68,21 @@ class Migration(migrations.Migration):
                 (
                     "unique_id",
                     models.IntegerField(
-                        default=django_afip.models.AuthTicket.default_unique_id,
+                        default=django_afip.models.default_unique_id,
                         verbose_name="unique id",
                     ),
                 ),
                 (
                     "generated",
                     models.DateTimeField(
-                        default=django_afip.models.AuthTicket.default_generated,
+                        default=django_afip.models.default_generated,
                         verbose_name="generated",
                     ),
                 ),
                 (
                     "expires",
                     models.DateTimeField(
-                        default=django_afip.models.AuthTicket.default_expires,
+                        default=django_afip.models.default_expires,
                         verbose_name="expires",
                     ),
                 ),
